@@ -2,14 +2,20 @@
 
 ;;; Code:
 
-(custom-add-loads 'extensions '("eldoc"))
+(autoload 'custom-add-loads "cus-load")
+
+(custom-add-loads 'convenience '("ibuffer"))
+(custom-add-loads 'matching '("hide-copyleft"))
 (custom-add-loads 'eldoc '("eldoc"))
 (custom-add-loads 'ielm '("ielm"))
 (custom-add-loads 'hide-copyleft '("hide-copyleft"))
+(custom-add-loads 'patcher-default '("patcher"))
 (custom-add-loads 'lisp '("checkdoc" "elp" "find-func" "ielm"))
-(custom-add-loads 'elp '("elp"))
-(custom-add-loads 'checkdoc '("checkdoc"))
 (custom-add-loads 'find-function '("find-func"))
-(custom-add-loads 'matching '("hide-copyleft"))
+(custom-add-loads 'ibuffer '("ibuffer"))
+(custom-add-loads 'checkdoc '("checkdoc"))
+(custom-add-loads 'elp '("elp"))
+(custom-add-loads 'patcher '("patcher"))
+(custom-add-loads 'extensions '("eldoc"))
 
 ;;; custom-load.el ends here
